@@ -73,7 +73,9 @@ def downloadImageSamples(folder='train'):
     '''
     #vedio==> https://drive.google.com/file/d/1076Ftdz8hxZkly-7QxYUR6kRJHSft-7s/view?usp=sharing
     #images==> https://drive.google.com/file/d/1zmpZY5D5vNwcxhNmTgBprisevixexA4I/view
-    file_id = '1zmpZY5D5vNwcxhNmTgBprisevixexA4I'
+    #          new image
+    #          https://drive.google.com/file/d/11FI4IqsbC-_QWz8qnuO7bRBW4LjSckDF/view?usp=sharing
+    file_id = '11FI4IqsbC-_QWz8qnuO7bRBW4LjSckDF'
     destination = 'train.zip'
     download_file_from_google_drive(file_id, destination)
     with zipfile.ZipFile(destination, mode='r') as myzip:
